<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AboutDlg</name>
    <message>
        <location filename="../about_dlg.cpp" line="28"/>
        <source>About </source>
        <translation>Over </translation>
    </message>
    <message>
        <location filename="../about_dlg.cpp" line="43"/>
        <source> is licenced under </source>
        <translation> is uitgebracht onder de </translation>
    </message>
    <message>
        <location filename="../about_dlg.cpp" line="45"/>
        <source>Package type: </source>
        <translation>Soort pakket: </translation>
    </message>
    <message>
        <location filename="../about_dlg.cpp" line="46"/>
        <source>Project website: </source>
        <translation>Projectwebsite: </translation>
    </message>
    <message>
        <location filename="../about_dlg.cpp" line="48"/>
        <source>Support </source>
        <translation>Ondersteunen </translation>
    </message>
    <message>
        <location filename="../about_dlg.cpp" line="48"/>
        <source> on Patreon: </source>
        <translation> op Patreon: </translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <location filename="../application.cpp" line="189"/>
        <source>Heimer Files</source>
        <translation>Heimer-bestanden</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="280"/>
        <source>Open File</source>
        <translation>Bestand openen</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="307"/>
        <source>Failed to save file.</source>
        <translation>Het bestand kan niet worden opgeslagen.</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="324"/>
        <source>Save File As</source>
        <translation>Bestand opslaan als</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="338"/>
        <source>File &apos;</source>
        <translation>Bestand</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="338"/>
        <source>&apos; saved.</source>
        <translation>&apos; is opgeslagen.</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="344"/>
        <source>Failed to save file as &apos;</source>
        <translation>Het bestand kan niet worden opgeslagen als &apos;</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="401"/>
        <source>Open an image</source>
        <translation>Afbeelding openen</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="401"/>
        <source>Image Files</source>
        <translation>Afbeeldingsbestanden</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="408"/>
        <source>Load image</source>
        <translation>Afbeelding laden</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="408"/>
        <source>Failed to load image &apos;</source>
        <translation>De afbeelding &apos; kan niet worden geladen</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="452"/>
        <source>The mind map has been modified.</source>
        <translation>De mindmap is aangepast.</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="453"/>
        <source>Do you want to save your changes?</source>
        <translation>Wil je de aanpassingen opslaan?</translation>
    </message>
</context>
<context>
    <name>DefaultsDlg</name>
    <message>
        <location filename="../defaults_dlg.cpp" line="32"/>
        <source>Defaults</source>
        <translation>Standaardwaarden</translation>
    </message>
    <message>
        <location filename="../defaults_dlg.cpp" line="56"/>
        <source>Edge Arrow Style</source>
        <translation>Pijlrandstijl</translation>
    </message>
    <message>
        <location filename="../defaults_dlg.cpp" line="60"/>
        <source>No arrow</source>
        <translation>Geen pijl</translation>
    </message>
    <message>
        <location filename="../defaults_dlg.cpp" line="61"/>
        <source>Single arrow</source>
        <translation>Enkele pijl</translation>
    </message>
    <message>
        <location filename="../defaults_dlg.cpp" line="62"/>
        <source>Double arrow</source>
        <translation>Dubbele pijl</translation>
    </message>
    <message>
        <location filename="../defaults_dlg.cpp" line="71"/>
        <source>Reversed direction</source>
        <translation>Omgekeerd</translation>
    </message>
</context>
<context>
    <name>EdgeContextMenu</name>
    <message>
        <location filename="../edge_context_menu.cpp" line="27"/>
        <source>Change direction</source>
        <translation>Richting aanpassen</translation>
    </message>
    <message>
        <location filename="../edge_context_menu.cpp" line="34"/>
        <source>Hide arrow</source>
        <translation>Pijl verbergen</translation>
    </message>
    <message>
        <location filename="../edge_context_menu.cpp" line="41"/>
        <source>Single arrow</source>
        <translation>Enkele pijl</translation>
    </message>
    <message>
        <location filename="../edge_context_menu.cpp" line="48"/>
        <source>Double arrow</source>
        <translation>Dubbele pijl</translation>
    </message>
    <message>
        <location filename="../edge_context_menu.cpp" line="55"/>
        <source>Delete edge</source>
        <translation>Rand verwijderen</translation>
    </message>
</context>
<context>
    <name>LayoutOptimizationDialog</name>
    <message>
        <location filename="../layout_optimization_dialog.cpp" line="36"/>
        <source>Optimize Layout</source>
        <translation>Indeling optimaliseren</translation>
    </message>
    <message>
        <location filename="../layout_optimization_dialog.cpp" line="88"/>
        <source>Aspect Ratio:</source>
        <translation>Beeldverhouding:</translation>
    </message>
    <message>
        <location filename="../layout_optimization_dialog.cpp" line="99"/>
        <source>Minimum Edge Length:</source>
        <translation>Minimale randlengte:</translation>
    </message>
    <message>
        <location filename="../layout_optimization_dialog.cpp" line="119"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../layout_optimization_dialog.cpp" line="122"/>
        <source>Optimize</source>
        <translation>Optimaliseren</translation>
    </message>
</context>
<context>
    <name>MainContextMenu</name>
    <message>
        <location filename="../main_context_menu.cpp" line="29"/>
        <source>Copy node</source>
        <translation>Knoop kopiëren</translation>
    </message>
    <message>
        <location filename="../main_context_menu.cpp" line="30"/>
        <source>Paste node</source>
        <translation>Knoop plakken</translation>
    </message>
    <message>
        <location filename="../main_context_menu.cpp" line="57"/>
        <source>Set background color</source>
        <translation>Achtergrondkleur instellen</translation>
    </message>
    <message>
        <location filename="../main_context_menu.cpp" line="63"/>
        <source>Set edge color</source>
        <translation>Randkleur instellen</translation>
    </message>
    <message>
        <location filename="../main_context_menu.cpp" line="69"/>
        <source>Set grid color</source>
        <translation>Roosterkleur instellen</translation>
    </message>
    <message>
        <location filename="../main_context_menu.cpp" line="75"/>
        <source>Create floating node</source>
        <translation>Zwevende knop invoegen</translation>
    </message>
    <message>
        <location filename="../main_context_menu.cpp" line="89"/>
        <source>Set node color</source>
        <translation>Knoopkleur instellen</translation>
    </message>
    <message>
        <location filename="../main_context_menu.cpp" line="95"/>
        <source>Set text color</source>
        <translation>Tekstkleur instellen</translation>
    </message>
    <message>
        <location filename="../main_context_menu.cpp" line="101"/>
        <source>Delete node</source>
        <translation>Knoop verwijderen</translation>
    </message>
    <message>
        <location filename="../main_context_menu.cpp" line="116"/>
        <source>Attach image...</source>
        <translation>Afbeelding bijvoegen...</translation>
    </message>
    <message>
        <location filename="../main_context_menu.cpp" line="123"/>
        <source>Remove attached image</source>
        <translation>Bijgevoegde afbeelding verwijderen</translation>
    </message>
    <message>
        <location filename="../main_context_menu.cpp" line="139"/>
        <source>&amp;Colors</source>
        <translation>&amp;Kleuren</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.cpp" line="55"/>
        <source>&amp;Save</source>
        <translation>Op&amp;slaan</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="56"/>
        <source>&amp;Save as</source>
        <translation>Op&amp;slaan als</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="57"/>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="58"/>
        <source>Redo</source>
        <translation>Opnieuw uitvoeren</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="63"/>
        <source>Copy on drag</source>
        <translation>Kopiëren bij verslepen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="64"/>
        <source>Show grid</source>
        <translation>Rooster tonen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Aanpassen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="111"/>
        <source>&amp;Colors</source>
        <translation>&amp;Kleuren</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="113"/>
        <source>Set background color</source>
        <translation>Achtergrondkleur instellen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="124"/>
        <source>Set edge color</source>
        <translation>Randkleur instellen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="135"/>
        <source>Set grid color</source>
        <translation>Roosterkleur instellen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="146"/>
        <source>Optimize layout</source>
        <translation>Indeling optimaliseren</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="165"/>
        <source>Corner radius:</source>
        <translation>Hoekstraal:</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="190"/>
        <source>Edge width:</source>
        <translation>Randbreedte:</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="214"/>
        <source>Text size:</source>
        <translation>Tekstgrootte:</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="238"/>
        <source>Grid size:</source>
        <translation>Roostergrootte:</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="261"/>
        <source>&amp;Export</source>
        <translation>&amp;Exporteren</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="264"/>
        <source>&amp;PNG</source>
        <translation>&amp;PNG</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="273"/>
        <source>&amp;SVG</source>
        <translation>&amp;SVG</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="287"/>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="290"/>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="298"/>
        <source>&amp;Open</source>
        <translation>&amp;Openen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="308"/>
        <source>Recent &amp;Files</source>
        <translation>Recente &amp;bestanden</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="338"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="352"/>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="355"/>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="362"/>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="371"/>
        <source>What&apos;s New</source>
        <translation>Wijzigingslog</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="381"/>
        <source>&amp;Settings</source>
        <translation>In&amp;stellingen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="384"/>
        <source>&amp;Defaults</source>
        <translation>Stan&amp;daardwaarden</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="415"/>
        <source>&amp;View</source>
        <translation>&amp;Beeld</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="418"/>
        <source>Full Screen</source>
        <translation>Beeldvullende modus</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="437"/>
        <source>Zoom In</source>
        <translation>Inzoomen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="443"/>
        <source>Zoom Out</source>
        <translation>Uitzoomen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="451"/>
        <source>&amp;Zoom To Fit</source>
        <translation>Automatisch inpa&amp;ssen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="498"/>
        <source>New File</source>
        <translation>Nieuw bestand</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="500"/>
        <source>Not Saved</source>
        <translation>Niet opgeslagen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="365"/>
        <source>About Qt</source>
        <translation>Over Qt</translation>
    </message>
</context>
<context>
    <name>PngExportDialog</name>
    <message>
        <location filename="../png_export_dialog.cpp" line="35"/>
        <source>Export to PNG Image</source>
        <translation>Exporteren naar png</translation>
    </message>
    <message>
        <location filename="../png_export_dialog.cpp" line="41"/>
        <source>Export As</source>
        <translation>Exporteren als</translation>
    </message>
    <message>
        <location filename="../png_export_dialog.cpp" line="43"/>
        <source>PNG Files</source>
        <translation>PNG-bestanden</translation>
    </message>
    <message>
        <location filename="../png_export_dialog.cpp" line="112"/>
        <source>Couldn&apos;t write to</source>
        <translation>Kan niet wegschrijven naar</translation>
    </message>
    <message>
        <location filename="../png_export_dialog.cpp" line="138"/>
        <source>Filename</source>
        <translation>Bestandsnaam</translation>
    </message>
    <message>
        <location filename="../png_export_dialog.cpp" line="144"/>
        <source>Export as..</source>
        <translation>Exporteren als...</translation>
    </message>
    <message>
        <location filename="../png_export_dialog.cpp" line="148"/>
        <source>Image Size</source>
        <translation>Afbeeldingsgrootte</translation>
    </message>
    <message>
        <location filename="../png_export_dialog.cpp" line="150"/>
        <source>Width (px):</source>
        <translation>Breedte (px):</translation>
    </message>
    <message>
        <location filename="../png_export_dialog.cpp" line="156"/>
        <source>Height (px):</source>
        <translation>Hoogte (px):</translation>
    </message>
    <message>
        <location filename="../png_export_dialog.cpp" line="164"/>
        <source>Background</source>
        <translation>Achtergrond</translation>
    </message>
    <message>
        <location filename="../png_export_dialog.cpp" line="167"/>
        <source>Transparent background</source>
        <translation>Doorzichtige achtergrond</translation>
    </message>
    <message>
        <location filename="../png_export_dialog.cpp" line="181"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../png_export_dialog.cpp" line="184"/>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../xml_reader.cpp" line="27"/>
        <source>Cannot open file: &apos;</source>
        <translation>Kan bestand niet openen: &apos;</translation>
    </message>
    <message>
        <location filename="../xml_reader.cpp" line="33"/>
        <source>Corrupted file: &apos;</source>
        <translation>Beschadigd bestand: &apos;</translation>
    </message>
</context>
<context>
    <name>SvgExportDialog</name>
    <message>
        <location filename="../svg_export_dialog.cpp" line="35"/>
        <source>Export to an SVG File</source>
        <translation>Exporteren naar svg</translation>
    </message>
    <message>
        <location filename="../svg_export_dialog.cpp" line="41"/>
        <source>Export As</source>
        <translation>Exporteren als</translation>
    </message>
    <message>
        <location filename="../svg_export_dialog.cpp" line="43"/>
        <source>SVG Files</source>
        <translation>SVG-bestanden</translation>
    </message>
    <message>
        <location filename="../svg_export_dialog.cpp" line="74"/>
        <source>Couldn&apos;t write to</source>
        <translation>Kan niet wegschrijven naar</translation>
    </message>
    <message>
        <location filename="../svg_export_dialog.cpp" line="98"/>
        <source>Filename</source>
        <translation>Bestandsnaam</translation>
    </message>
    <message>
        <location filename="../svg_export_dialog.cpp" line="104"/>
        <source>Export as..</source>
        <translation>Exporteren als...</translation>
    </message>
    <message>
        <location filename="../svg_export_dialog.cpp" line="118"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../svg_export_dialog.cpp" line="121"/>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
</context>
<context>
    <name>WhatsNewDlg</name>
    <message>
        <location filename="../whats_new_dlg.cpp" line="29"/>
        <source>What&apos;s New</source>
        <translation>Wijzigingslog</translation>
    </message>
</context>
</TS>
